note 44614 deleted from function.include by peehaa

From: Date: Fri, 09 Dec 2016 22:43:00 +0000
Subject: note 44614 deleted from function.include by peehaa
References: 1  Groups: php.notes 
Request: Send a blank email to php-notes+get-208375@lists.php.net to get a copy of this message
Note Submitter: mattcimino at gardiners dot com ---- To avoid painfully SLOW INCLUDES under IIS be sure to set "output_buffering = on" in php.ini. File includes dropped from about 2 seconds to 0 seconds when this was set.

« previous php.notes (#208375) next »